using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Autofac;
using FitConnect.Models;
using FitConnect.Services.Interfaces;
using FitConnect.Services.Models.v1.Submission;
using Microsoft.Extensions.Logging;
using Moq;

namespace BasicUnitTest.Mocking;

public static class MockDependencyContainer {
    public static IContainer Container => _container ??= Create();

    private static IContainer? _container;

    private static SubmissionDto CreateSubmission(string id) {
        var result = new SubmissionDto() {
            SubmissionId = id,
            DestinationId = Guid.NewGuid().ToString(),
            CaseId = Guid.NewGuid().ToString(),
        };

        var data = @"{""name"":""John Doe""}";
        var attachments = new List<Attachment>();

        return result;
    }

    private static IContainer Create() {
        var builder = new ContainerBuilder();
        var submissionService = new Mock<ISubmissionService>();
        submissionService.Setup(
            s => s.GetSubmissionAsync(It.IsAny<string>())).Returns(
            (string id) => Task.FromResult(CreateSubmission(id))
        );

        builder.RegisterInstance(submissionService.Object);
        builder.RegisterInstance(new Mock<IOAuthService>().Object);
        builder.RegisterInstance(new Mock<IRouteService>().Object);
        builder.RegisterInstance(new Mock<ICasesService>().Object);
        builder.RegisterInstance(new Mock<IDestinationService>().Object);
        builder.RegisterInstance(new Mock<ILogger>().Object);
        return builder.Build();
    }
}
