﻿using System.Security.Claims;
using System.Security.Cryptography;
using System.Text;
using Microsoft.IdentityModel.Tokens;
using System.IdentityModel.Tokens.Jwt;

namespace FitConnect.SelfServicePortal;

public class KeyGenerator {
    private readonly byte[] signingKey;
    private readonly byte[] signingVerifyKey;
    private readonly byte[] encryptionKey;
    private readonly byte[] decryptionKey;

    public KeyGenerator() {
        var aes = RSA.Create();
        signingKey = aes.ExportRSAPrivateKey();
        signingVerifyKey = aes.ExportRSAPublicKey();

        aes = RSA.Create();
        decryptionKey = aes.ExportRSAPrivateKey();
        encryptionKey = aes.ExportRSAPublicKey();
        Console.WriteLine(Base64UrlEncoder.Encode(encryptionKey));
    }


    public JsonWebKey GenerateSigningKey() {
        // Generate a signing key
        var signingKey = new SymmetricSecurityKey(this.signingKey);

// Create a JWK from the signing key
        var jwkKey = new JsonWebKey {
            Kty = "oct",
            Alg = SecurityAlgorithms.RsaSsaPssSha512Signature,
            Use = "sig",
            Kid = "signing-key",
            K = Convert.ToBase64String(signingKey.Key)
        };

// Output the JWK key
        return jwkKey;
    }

    public JsonWebKey GenerateEncryptionKey() {
// Generate an encryption key
        var encryptionKey =
            new SymmetricSecurityKey(this.encryptionKey);

// Create a JWK from the encryption key
        var jwkKey = new JsonWebKey {
            Kty = "oct",
            Alg = SecurityAlgorithms.RsaOaepKeyWrap,
            Use = "enc",
            Kid = "encryption-key",
            K = Convert.ToBase64String(encryptionKey.Key)
        };

// Output the JWK key
        return jwkKey;
    }
}
